@@ -6,7 +6,7 @@
  * GeographicLib is Copyright (c) Charles Karney (2010-2012)
  * <charles@karney.com> and licensed under the MIT/X11 License.
  * For more information, see
- * http://geographiclib.sourceforge.net/
+ * https://geographiclib.sourceforge.io/
  **********************************************************************/
 #pragma once
 #include "NETGeographicLib.h"
@@ -28,7 +28,7 @@ namespace NETGeographicLib
    * labeled &phi;, longitude &lambda; (with &lambda;<sub>12</sub> =
    * &lambda;<sub>2</sub> &minus; &lambda;<sub>1</sub>), and azimuth &alpha;.
    *
-   * <img src="http://upload.wikimedia.org/wikipedia/commons/c/cb/Geodesic_problem_on_an_ellipsoid.svg" width=250 alt="spheroidal triangle">
+   * <img src="https://upload.wikimedia.org/wikipedia/commons/c/cb/Geodesic_problem_on_an_ellipsoid.svg" width=250 alt="spheroidal triangle">
    *
    * Given \e lat1, \e lon1, \e azi1, and \e s12, we can determine \e lat2, \e
    * lon2, and \e azi2.  This is the \e direct geodesic problem and its
@@ -115,13 +115,13 @@ namespace NETGeographicLib
    *   which can be generated by setting [\e azi1, \e azi2] &rarr; [\e azi1, \e
    *   azi2] + [\e d, &minus;\e d], for arbitrary \e d.  (For spheres, this
    *   prescription applies when points 1 and 2 are antipodal.)
-   * - s12 = 0 (coincident points).  There are infinitely many geodesics which
-   *   can be generated by setting [\e azi1, \e azi2] &rarr; [\e azi1, \e azi2]
-   *   + [\e d, \e d], for arbitrary \e d.
+   * - \e s12 = 0 (coincident points).  There are infinitely many geodesics
+   *   which can be generated by setting [\e azi1, \e azi2] &rarr;
+   *   [\e azi1, \e azi2] + [\e d, \e d], for arbitrary \e d.
    *
    * The calculations are accurate to better than 15 nm (15 nanometers) for the
    * WGS84 ellipsoid.  See Sec. 9 of
-   * <a href="http://arxiv.org/abs/1102.1215v1">arXiv:1102.1215v1</a> for
+   * <a href="https://arxiv.org/abs/1102.1215v1">arXiv:1102.1215v1</a> for
    * details.  The algorithms used by this class are based on series expansions
    * using the flattening \e f as a small parameter.  These are only accurate
    * for |<i>f</i>| &lt; 0.02; however reasonably accurate results will be
@@ -140,12 +140,12 @@ namespace NETGeographicLib
    *
    * The algorithms are described in
    * - C. F. F. Karney,
-   *   <a href="https://dx.doi.org/10.1007/s00190-012-0578-z">
+   *   <a href="https://doi.org/10.1007/s00190-012-0578-z">
    *   Algorithms for geodesics</a>,
    *   J. Geodesy <b>87</b>, 43--55 (2013);
-   *   DOI: <a href="https://dx.doi.org/10.1007/s00190-012-0578-z">
+   *   DOI: <a href="https://doi.org/10.1007/s00190-012-0578-z">
    *   10.1007/s00190-012-0578-z</a>;
-   *   addenda: <a href="http://geographiclib.sf.net/geod-addenda.html">
+   *   addenda: <a href="https://geographiclib.sourceforge.io/geod-addenda.html">
    *   geod-addenda.html</a>.
    * .
    * For more information on geodesics see \ref geodesic.
@@ -235,12 +235,10 @@ namespace NETGeographicLib
           **********************************************************************/
          AREA          = 1U<<14 | unsigned(captype::CAP_C4),
          /**
-          * Unroll \e lon2 in the direct calculation.  (This flag used to be
-          * called LONG_NOWRAP.)
+          * Unroll \e lon2 in the direct calculation.
           * @hideinitializer
           **********************************************************************/
          LONG_UNROLL   = 1U<<15,
-         LONG_NOWRAP   = LONG_UNROLL,
          /**
           * All capabilities, calculate everything.  (LONG_UNROLL is not
           * included in this mask.)
@@ -726,6 +724,99 @@ namespace NETGeographicLib
         GeodesicLine^ Line(double lat1, double lon1, double azi1,
                            NETGeographicLib::Mask caps );
 
+        /**
+        * Define a GeodesicLine in terms of the inverse geodesic problem.
+        *
+        * @param[in] lat1 latitude of point 1 (degrees).
+        * @param[in] lon1 longitude of point 1 (degrees).
+        * @param[in] lat2 latitude of point 2 (degrees).
+        * @param[in] lon2 longitude of point 2 (degrees).
+        * @param[in] caps bitor'ed combination of Geodesic::mask values
+        *   specifying the capabilities the GeodesicLine object should possess,
+        *   i.e., which quantities can be returned in calls to
+        *   GeodesicLine::Position.
+        * @return a GeodesicLine object.
+        *
+        * This function sets point 3 of the GeodesicLine to correspond to point 2
+        * of the inverse geodesic problem.
+        *
+        * \e lat1 and \e lat2 should be in the range [&minus;90&deg;, 90&deg;].
+        **********************************************************************/
+        GeodesicLine^ InverseLine(double lat1, double lon1, double lat2,
+            double lon2, NETGeographicLib::Mask caps);
+
+        /**
+        * Define a GeodesicLine in terms of the direct geodesic problem specified
+        * in terms of distance.
+        *
+        * @param[in] lat1 latitude of point 1 (degrees).
+        * @param[in] lon1 longitude of point 1 (degrees).
+        * @param[in] azi1 azimuth at point 1 (degrees).
+        * @param[in] s12 distance between point 1 and point 2 (meters); it can be
+        *   negative.
+        * @param[in] caps bitor'ed combination of Geodesic::mask values
+        *   specifying the capabilities the GeodesicLine object should possess,
+        *   i.e., which quantities can be returned in calls to
+        *   GeodesicLine::Position.
+        * @return a GeodesicLine object.
+        *
+        * This function sets point 3 of the GeodesicLine to correspond to point 2
+        * of the direct geodesic problem.
+        *
+        * \e lat1 should be in the range [&minus;90&deg;, 90&deg;].
+        **********************************************************************/
+        GeodesicLine^ DirectLine(double lat1, double lon1, double azi1,
+            double s12, NETGeographicLib::Mask caps);
+
+        /**
+        * Define a GeodesicLine in terms of the direct geodesic problem specified
+        * in terms of arc length.
+        *
+        * @param[in] lat1 latitude of point 1 (degrees).
+        * @param[in] lon1 longitude of point 1 (degrees).
+        * @param[in] azi1 azimuth at point 1 (degrees).
+        * @param[in] a12 arc length between point 1 and point 2 (degrees); it can
+        *   be negative.
+        * @param[in] caps bitor'ed combination of Geodesic::mask values
+        *   specifying the capabilities the GeodesicLine object should possess,
+        *   i.e., which quantities can be returned in calls to
+        *   GeodesicLine::Position.
+        * @return a GeodesicLine object.
+        *
+        * This function sets point 3 of the GeodesicLine to correspond to point 2
+        * of the direct geodesic problem.
+        *
+        * \e lat1 should be in the range [&minus;90&deg;, 90&deg;].
+        **********************************************************************/
+        GeodesicLine^ ArcDirectLine(double lat1, double lon1, double azi1,
+            double a12, NETGeographicLib::Mask caps);
+
+        /**
+        * Define a GeodesicLine in terms of the direct geodesic problem specified
+        * in terms of either distance or arc length.
+        *
+        * @param[in] lat1 latitude of point 1 (degrees).
+        * @param[in] lon1 longitude of point 1 (degrees).
+        * @param[in] azi1 azimuth at point 1 (degrees).
+        * @param[in] arcmode boolean flag determining the meaning of the \e
+        *   s12_a12.
+        * @param[in] s12_a12 if \e arcmode is false, this is the distance between
+        *   point 1 and point 2 (meters); otherwise it is the arc length between
+        *   point 1 and point 2 (degrees); it can be negative.
+        * @param[in] caps bitor'ed combination of Geodesic::mask values
+        *   specifying the capabilities the GeodesicLine object should possess,
+        *   i.e., which quantities can be returned in calls to
+        *   GeodesicLine::Position.
+        * @return a GeodesicLine object.
+        *
+        * This function sets point 3 of the GeodesicLine to correspond to point 2
+        * of the direct geodesic problem.
+        *
+        * \e lat1 should be in the range [&minus;90&deg;, 90&deg;].
+        **********************************************************************/
+        GeodesicLine^ GenDirectLine(double lat1, double lon1, double azi1,
+            bool arcmode, double s12_a12,
+            NETGeographicLib::Mask caps);
         ///@}
 
         /** \name Inspector functions.
