@@ -37,7 +37,7 @@
 using namespace std;
 using namespace GeographicLib;
 
-int main(int argc, char* argv[]) {
+int main(int argc, const char* const argv[]) {
   // Hardwired for 3 args:
   // 1 = the gravity model (e.g., egm2008)
   // 2 = intervals per degree
@@ -52,7 +52,7 @@ int main(int argc, char* argv[]) {
     int ndigits = Utility::set_digits();
     string model(argv[1]);
     // Number of intervals per degree
-    int ndeg = Utility::num<int>(string(argv[2]));
+    int ndeg = Utility::val<int>(string(argv[2]));
     string filename(argv[3]);
     GravityModel g(model);
     int
@@ -108,5 +108,4 @@ int main(int argc, char* argv[]) {
     cerr << "Caught unknown exception\n";
     return 1;
   }
-  return 0;
 }
