@@ -2,7 +2,7 @@
  * \file LambertConformalConic.hpp
  * \brief Header for GeographicLib::LambertConformalConic class
  *
- * Copyright (c) Charles Karney (2010-2016) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2010-2017) <charles@karney.com> and licensed
  * under the MIT/X11 License.  For more information, see
  * https://geographiclib.sourceforge.io/
  **********************************************************************/
@@ -42,7 +42,13 @@ namespace GeographicLib {
    * parallels where one is a pole is singular and is disallowed.  The central
    * meridian (which is a trivial shift of the longitude) is specified as the
    * \e lon0 argument of the LambertConformalConic::Forward and
-   * LambertConformalConic::Reverse functions.  There is no provision in this
+   * LambertConformalConic::Reverse functions.
+   *
+   * This class also returns the meridian convergence \e gamma and scale \e k.
+   * The meridian convergence is the bearing of grid north (the \e y axis)
+   * measured clockwise from true north.
+   *
+   * There is no provision in this
    * class for specifying a false easting or false northing or a different
    * latitude of origin.  However these are can be simply included by the
    * calling function.  For example the Pennsylvania South state coordinate
@@ -62,7 +68,7 @@ namespace GeographicLib {
     real _sign, _n, _nc, _t0nm1, _scale, _lat0, _k0;
     real _scbet0, _tchi0, _scchi0, _psi0, _nrho0, _drhomax;
     static const int numit_ = 5;
-    static inline real hyp(real x) { return Math::hypot(real(1), x); }
+    static real hyp(real x) { return Math::hypot(real(1), x); }
     // Divided differences
     // Definition: Df(x,y) = (f(x)-f(y))/(x-y)
     // See:
@@ -80,53 +86,53 @@ namespace GeographicLib {
     //                = Df(x,y)*(g(x)+g(y))/2 + Dg(x,y)*(f(x)+f(y))/2
     //
     // hyp(x) = sqrt(1+x^2): Dhyp(x,y) = (x+y)/(hyp(x)+hyp(y))
-    static inline real Dhyp(real x, real y, real hx, real hy)
+    static real Dhyp(real x, real y, real hx, real hy)
     // hx = hyp(x)
     { return (x + y) / (hx + hy); }
     // sn(x) = x/sqrt(1+x^2): Dsn(x,y) = (x+y)/((sn(x)+sn(y))*(1+x^2)*(1+y^2))
-    static inline real Dsn(real x, real y, real sx, real sy) {
+    static real Dsn(real x, real y, real sx, real sy) {
       // sx = x/hyp(x)
       real t = x * y;
       return t > 0 ? (x + y) * Math::sq( (sx * sy)/t ) / (sx + sy) :
         (x - y != 0 ? (sx - sy) / (x - y) : 1);
     }
     // Dlog1p(x,y) = log1p((x-y)/(1+y))/(x-y)
-    static inline real Dlog1p(real x, real y) {
+    static real Dlog1p(real x, real y) {
       real t = x - y; if (t < 0) { t = -t; y = x; }
-      return t ? Math::log1p(t / (1 + y)) / t : 1 / (1 + x);
+      return t != 0 ? Math::log1p(t / (1 + y)) / t : 1 / (1 + x);
     }
     // Dexp(x,y) = exp((x+y)/2) * 2*sinh((x-y)/2)/(x-y)
-    static inline real Dexp(real x, real y) {
+    static real Dexp(real x, real y) {
       using std::sinh; using std::exp;
       real t = (x - y)/2;
-      return (t ? sinh(t)/t : 1) * exp((x + y)/2);
+      return (t != 0 ? sinh(t)/t : 1) * exp((x + y)/2);
     }
     // Dsinh(x,y) = 2*sinh((x-y)/2)/(x-y) * cosh((x+y)/2)
     //   cosh((x+y)/2) = (c+sinh(x)*sinh(y)/c)/2
     //   c=sqrt((1+cosh(x))*(1+cosh(y)))
     //   cosh((x+y)/2) = sqrt( (sinh(x)*sinh(y) + cosh(x)*cosh(y) + 1)/2 )
-    static inline real Dsinh(real x, real y, real sx, real sy, real cx, real cy)
+    static real Dsinh(real x, real y, real sx, real sy, real cx, real cy)
     // sx = sinh(x), cx = cosh(x)
     {
       // real t = (x - y)/2, c = sqrt((1 + cx) * (1 + cy));
       // return (t ? sinh(t)/t : real(1)) * (c + sx * sy / c) /2;
       using std::sinh; using std::sqrt;
       real t = (x - y)/2;
-      return (t ? sinh(t)/t : 1) * sqrt((sx * sy + cx * cy + 1) /2);
+      return (t != 0 ? sinh(t)/t : 1) * sqrt((sx * sy + cx * cy + 1) /2);
     }
     // Dasinh(x,y) = asinh((x-y)*(x+y)/(x*sqrt(1+y^2)+y*sqrt(1+x^2)))/(x-y)
     //             = asinh((x*sqrt(1+y^2)-y*sqrt(1+x^2)))/(x-y)
-    static inline real Dasinh(real x, real y, real hx, real hy) {
+    static real Dasinh(real x, real y, real hx, real hy) {
       // hx = hyp(x)
       real t = x - y;
-      return t ?
+      return t != 0 ?
         Math::asinh(x*y > 0 ? t * (x+y) / (x*hy + y*hx) : x*hy - y*hx) / t :
         1/hx;
     }
     // Deatanhe(x,y) = eatanhe((x-y)/(1-e^2*x*y))/(x-y)
-    inline real Deatanhe(real x, real y) const {
+    real Deatanhe(real x, real y) const {
       real t = x - y, d = 1 - _e2 * x * y;
-      return t ? Math::eatanhe(t / d, _es) / t : _e2 / d;
+      return t != 0 ? Math::eatanhe(t / d, _es) / t : _e2 / d;
     }
     void Init(real sphi1, real cphi1, real sphi2, real cphi2, real k1);
   public:
