@@ -1,9 +1,9 @@
 /**
  * Implementation of the net.sf.geographiclib.GeoMath class
  *
- * Copyright (c) Charles Karney (2013-2016) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2013-2017) <charles@karney.com> and licensed
  * under the MIT/X11 License.  For more information, see
- * http://geographiclib.sourceforge.net/
+ * https://geographiclib.sourceforge.io/
  **********************************************************************/
 package net.sf.geographiclib;
 
@@ -51,8 +51,8 @@ public class GeoMath {
     double a = Math.max(x, y), b = Math.min(x, y) / (a != 0 ? a : 1);
     return a * Math.sqrt(1 + b * b);
     // For an alternative method see
-    // C. Moler and D. Morrision (1983) https://dx.doi.org/10.1147/rd.276.0577
-    // and A. A. Dubrulle (1983) https://dx.doi.org/10.1147/rd.276.0582
+    // C. Moler and D. Morrision (1983) https://doi.org/10.1147/rd.276.0577
+    // and A. A. Dubrulle (1983) https://doi.org/10.1147/rd.276.0582
   }
 
   /**
@@ -60,7 +60,7 @@ public class GeoMath {
    * later, Math.log1p can be used.
    * <p>
    * This is taken from D. Goldberg,
-   * <a href="https://dx.doi.org/10.1145/103162.103163">What every computer
+   * <a href="https://doi.org/10.1145/103162.103163">What every computer
    * scientist should know about floating-point arithmetic</a> (1991),
    * Theorem 4.  See also, N. J. Higham, Accuracy and Stability of Numerical
    * Algorithms, 2nd Edition (SIAM, 2002), Answer to Problem 1.5, p 528.
@@ -97,7 +97,7 @@ public class GeoMath {
    * Copy the sign.  In Java version 1.6 and later, Math.copysign can be used.
    * <p>
    * @param x gives the magitude of the result.
-   * @param x gives the sign of the result.
+   * @param y gives the sign of the result.
    * @return value with the magnitude of <i>x</i> and with the sign of
    *   <i>y</i>.
    **********************************************************************/
@@ -190,7 +190,7 @@ public class GeoMath {
    **********************************************************************/
   public static double AngNormalize(double x) {
     x = x % 360.0;
-    return x < -180 ? x + 360 : (x < 180 ? x : x - 360);
+    return x <= -180 ? x + 360 : (x <= 180 ? x : x - 360);
   }
 
   /**
@@ -221,10 +221,10 @@ public class GeoMath {
   public static Pair AngDiff(double x, double y) {
     double d, t;
     {
-      Pair r = sum(AngNormalize(x), AngNormalize(-y));
-      d = - AngNormalize(r.first); t = r.second;
+      Pair r = sum(AngNormalize(-x), AngNormalize(y));
+      d = AngNormalize(r.first); t = r.second;
     }
-    return sum(d == 180 && t < 0 ? -180 : d, -t);
+    return sum(d == 180 && t > 0 ? -180 : d, t);
   }
 
   /**
@@ -250,11 +250,12 @@ public class GeoMath {
     double s = Math.sin(r), c = Math.cos(r);
     double sinx, cosx;
     switch (q & 3) {
-    case  0: sinx =     s; cosx =     c; break;
-    case  1: sinx =     c; cosx = 0 - s; break;
-    case  2: sinx = 0 - s; cosx = 0 - c; break;
-    default: sinx = 0 - c; cosx =     s; break; // case 3
+    case  0: sinx =  s; cosx =  c; break;
+    case  1: sinx =  c; cosx = -s; break;
+    case  2: sinx = -s; cosx = -c; break;
+    default: sinx = -c; cosx =  s; break; // case 3
     }
+    if (x != 0) { sinx += 0.0; cosx += 0.0; }
     return new Pair(sinx, cosx);
   }
 
@@ -265,9 +266,9 @@ public class GeoMath {
    * @param x the cosine of the angle
    * @return atan2(<i>y</i>, <i>x</i>) in degrees.
    *
-   * The result is in the range [&minus;180&deg; 180&deg;).  N.B.,
-   * atan2d(&plusmn;0, &minus;1) = &minus;180&deg;; atan2d(+&epsilon;,
-   * &minus;1) = +180&deg;, for &epsilon; positive and tiny;
+   * The result is in the range (&minus;180&deg; 180&deg;].  N.B.,
+   * atan2d(&plusmn;0, &minus;1) = +180&deg;; atan2d(&minus;&epsilon;,
+   * &minus;1) = &minus;180&deg;, for &epsilon; positive and tiny;
    * atan2d(&plusmn;0, 1) = &plusmn;0&deg;.
    **********************************************************************/
   public static double atan2d(double y, double x) {
@@ -287,7 +288,7 @@ public class GeoMath {
       //   case 0: ang = 0 + ang; break;
       //
       // and handle mpfr as in AngRound.
-    case 1: ang = (y > 0 ? 180 : -180) - ang; break;
+    case 1: ang = (y >= 0 ? 180 : -180) - ang; break;
     case 2: ang =  90 - ang; break;
     case 3: ang = -90 + ang; break;
     }
