@@ -39,7 +39,7 @@ function [s12, azi1, azi2, S12, m12, M12, M21, a12] = geoddistance ...
 %     * The algorithm converges for all pairs of input points.
 %     * Additional properties of the geodesic are calcuated.
 %
-%   See also GEODDOC, GEODRECKON, GEODAREA, DEFAULTELLIPSOID.
+%   See also GEODDOC, GEODRECKON, GEODAREA, DEFAULTELLIPSOID, FLAT2ECC.
 
 % Copyright (c) Charles Karney (2012-2017) <charles@karney.com>.
 %
@@ -172,7 +172,8 @@ function [s12, azi1, azi2, S12, m12, M12, M21, a12] = geoddistance ...
   if any(g)
     dnm = Z;
     [sig12(g), salp1(g), calp1(g), salp2(g), calp2(g), dnm(g)] = ...
-        InverseStart(sbet1(g), cbet1(g), dn1(g), sbet2(g), cbet2(g), dn2(g), ...
+        InverseStart(sbet1(g), cbet1(g), dn1(g), ...
+                     sbet2(g), cbet2(g), dn2(g), ...
                      lam12(g), slam12(g), clam12(g), f, A3x);
 
     s = g & sig12 >= 0;
