@@ -37,9 +37,9 @@ function [lat, lon, gam, k] = tranmerc_inv(lat0, lon0, x, y, ellipsoid)
 %   can be continued accurately over the poles to the opposite meridian.
 %
 %   See also PROJDOC, TRANMERC_FWD, UTMUPS_FWD, UTMUPS_INV,
-%     DEFAULTELLIPSOID.
+%     DEFAULTELLIPSOID, FLAT2ECC.
 
-% Copyright (c) Charles Karney (2012-2015) <charles@karney.com>.
+% Copyright (c) Charles Karney (2012-2017) <charles@karney.com>.
 
   narginchk(4, 5)
   if nargin < 5, ellipsoid = defaultellipsoid; end
@@ -86,34 +86,28 @@ function [lat, lon, gam, k] = tranmerc_inv(lat0, lon0, x, y, ellipsoid)
 
   c0 = cos(2 * xi); ch0 = cosh(2 * eta);
   s0 = sin(2 * xi); sh0 = sinh(2 * eta);
-  ar = 2 * c0 .* ch0; ai = -2 * s0 .* sh0;
+  a = 2 * complex(c0 .* ch0, -s0 .* sh0);
   j = maxpow;
-  xip0 = Z; yr0 = Z;
+  y0 = complex(Z); y1 = y0;
+  z0 = y0; z1 = y0;
   if mod(j, 2)
-    xip0 = xip0 + bet(j);
-    yr0 = yr0 - 2 * maxpow * bet(j);
+    y0 = y0 + bet(j);
+    z0 = z0 - 2*j * bet(j);
     j = j - 1;
   end
-  xip1 = Z; etap0 = Z; etap1 = Z;
-  yi0 = Z; yr1 = Z; yi1 = Z;
   for j = j : -2 : 1
-    xip1  = ar .* xip0 - ai .* etap0 - xip1 - bet(j);
-    etap1 = ai .* xip0 + ar .* etap0 - etap1;
-    yr1 = ar .* yr0 - ai .* yi0 - yr1 - 2 * j * bet(j);
-    yi1 = ai .* yr0 + ar .* yi0 - yi1;
-    xip0  = ar .* xip1 - ai .* etap1 - xip0 - bet(j-1);
-    etap0 = ai .* xip1 + ar .* etap1 - etap0;
-    yr0 = ar .* yr1 - ai .* yi1 - yr0 - 2 * (j-1) * bet(j-1);
-    yi0 = ai .* yr1 + ar .* yi1 - yi0;
+    y1 = a .* y0 - y1 -       bet(j);
+    z1 = a .* z0 - z1 - 2*j * bet(j);
+    y0 = a .* y1 - y0 -           bet(j-1);
+    z0 = a .* z1 - z0 - 2*(j-1) * bet(j-1);
   end
-  ar = ar/2; ai = ai/2;
-  yr1 = 1 - yr1 + ar .* yr0 - ai .* yi0;
-  yi1 =   - yi1 + ai .* yr0 + ar .* yi0;
-  ar = s0 .* ch0; ai = c0 .* sh0;
-  xip  = xi  + ar .* xip0 - ai .* etap0;
-  etap = eta + ai .* xip0 + ar .* etap0;
-  gam = atan2dx(yi1, yr1);
-  k = b1 ./ hypot(yr1, yi1);
+  a = a/2;
+  z1 = 1 - z1 + z0 .* a;
+  a = complex(s0 .* ch0, c0 .* sh0);
+  y1 = complex(xi, eta) + y0 .* a;
+  gam = atan2dx(imag(z1), real(z1));
+  k = b1 ./ abs(z1);
+  xip = real(y1); etap = imag(y1);
   s = sinh(etap);
   c = max(0, cos(xip));
   r = hypot(s, c);
