@@ -1,21 +1,59 @@
-"""geodesicline.py: transcription of GeographicLib::GeodesicLine class."""
+"""Define the :class:`~geographiclib.geodesicline.GeodesicLine` class
+
+The constructor defines the starting point of the line.  Points on the
+line are given by
+
+  * :meth:`~geographiclib.geodesicline.GeodesicLine.Position` position
+    given in terms of distance
+  * :meth:`~geographiclib.geodesicline.GeodesicLine.ArcPosition` position
+    given in terms of spherical arc length
+
+A reference point 3 can be defined with
+
+  * :meth:`~geographiclib.geodesicline.GeodesicLine.SetDistance` set
+    position of 3 in terms of the distance from the starting point
+  * :meth:`~geographiclib.geodesicline.GeodesicLine.SetArc` set
+    position of 3 in terms of the spherical arc length from the starting point
+
+The object can also be constructed by
+
+  * :meth:`Geodesic.Line <geographiclib.geodesic.Geodesic.Line>`
+  * :meth:`Geodesic.DirectLine <geographiclib.geodesic.Geodesic.DirectLine>`
+  * :meth:`Geodesic.ArcDirectLine
+    <geographiclib.geodesic.Geodesic.ArcDirectLine>`
+  * :meth:`Geodesic.InverseLine <geographiclib.geodesic.Geodesic.InverseLine>`
+
+The public attributes for this class are
+
+  * :attr:`~geographiclib.geodesicline.GeodesicLine.a`
+    :attr:`~geographiclib.geodesicline.GeodesicLine.f`
+    :attr:`~geographiclib.geodesicline.GeodesicLine.caps`
+    :attr:`~geographiclib.geodesicline.GeodesicLine.lat1`
+    :attr:`~geographiclib.geodesicline.GeodesicLine.lon1`
+    :attr:`~geographiclib.geodesicline.GeodesicLine.azi1`
+    :attr:`~geographiclib.geodesicline.GeodesicLine.salp1`
+    :attr:`~geographiclib.geodesicline.GeodesicLine.calp1`
+    :attr:`~geographiclib.geodesicline.GeodesicLine.s13`
+    :attr:`~geographiclib.geodesicline.GeodesicLine.a13`
+
+"""
 # geodesicline.py
 #
 # This is a rather literal translation of the GeographicLib::GeodesicLine class
 # to python.  See the documentation for the C++ class for more information at
 #
-#    http://geographiclib.sourceforge.net/html/annotated.html
+#    https://geographiclib.sourceforge.io/html/annotated.html
 #
 # The algorithms are derived in
 #
 #    Charles F. F. Karney,
 #    Algorithms for geodesics, J. Geodesy 87, 43-55 (2013),
-#    https://dx.doi.org/10.1007/s00190-012-0578-z
-#    Addenda: http://geographiclib.sf.net/geod-addenda.html
+#    https://doi.org/10.1007/s00190-012-0578-z
+#    Addenda: https://geographiclib.sourceforge.io/geod-addenda.html
 #
-# Copyright (c) Charles Karney (2011-2015) <charles@karney.com> and licensed
+# Copyright (c) Charles Karney (2011-2016) <charles@karney.com> and licensed
 # under the MIT/X11 License.  For more information, see
-# http://geographiclib.sourceforge.net/
+# https://geographiclib.sourceforge.io/
 ######################################################################
 
 import math
@@ -25,42 +63,53 @@ from geographiclib.geodesiccapability import GeodesicCapability
 class GeodesicLine(object):
   """Points on a geodesic path"""
 
-  def __init__(self, geod, lat1, lon1, azi1, caps = GeodesicCapability.ALL):
-    """Construct a GeodesicLine object describing a geodesic line
-    starting at (lat1, lon1) with azimuth azi1.  geod is a Geodesic
-    object (which embodies the ellipsoid parameters).  caps is caps is
-    an or'ed combination of bit the following values indicating the
-    capabilities of the returned object
+  def __init__(self, geod, lat1, lon1, azi1,
+               caps = GeodesicCapability.STANDARD |
+               GeodesicCapability.DISTANCE_IN,
+               salp1 = Math.nan, calp1 = Math.nan):
+    """Construct a GeodesicLine object
 
-      Geodesic.LATITUDE
-      Geodesic.LONGITUDE
-      Geodesic.AZIMUTH
-      Geodesic.DISTANCE
-      Geodesic.STANDARD (all of the above)
-      Geodesic.REDUCEDLENGTH
-      Geodesic.GEODESICSCALE
-      Geodesic.AREA
-      Geodesic.DISTANCE_IN
-      Geodesic.ALL (all of the above)
+    :param geod: a :class:`~geographiclib.geodesic.Geodesic` object
+    :param lat1: latitude of the first point in degrees
+    :param lon1: longitude of the first point in degrees
+    :param azi1: azimuth at the first point in degrees
+    :param caps: the :ref:`capabilities <outmask>`
 
-    The default value of caps is ALL.
+    This creates an object allowing points along a geodesic starting at
+    (*lat1*, *lon1*), with azimuth *azi1* to be found.  The default
+    value of *caps* is STANDARD | DISTANCE_IN.  The optional parameters
+    *salp1* and *calp1* should not be supplied; they are part of the
+    private interface.
 
     """
 
     from geographiclib.geodesic import Geodesic
-    self._a = geod._a
-    self._f = geod._f
+    self.a = geod.a
+    """The equatorial radius in meters (readonly)"""
+    self.f = geod.f
+    """The flattening (readonly)"""
     self._b = geod._b
     self._c2 = geod._c2
     self._f1 = geod._f1
-    self._caps = (caps | Geodesic.LATITUDE | Geodesic.AZIMUTH |
+    self.caps = (caps | Geodesic.LATITUDE | Geodesic.AZIMUTH |
                   Geodesic.LONG_UNROLL)
+    """the capabilities (readonly)"""
 
     # Guard against underflow in salp0
-    self._lat1 = Math.LatFix(lat1)
-    self._lon1 = lon1
-    self._azi1 = Math.AngNormalize(azi1)
-    self._salp1, self._calp1 = Math.sincosd(Math.AngRound(azi1))
+    self.lat1 = Math.LatFix(lat1)
+    """the latitude of the first point in degrees (readonly)"""
+    self.lon1 = lon1
+    """the longitude of the first point in degrees (readonly)"""
+    if Math.isnan(salp1) or Math.isnan(calp1):
+      self.azi1 = Math.AngNormalize(azi1)
+      self.salp1, self.calp1 = Math.sincosd(Math.AngRound(azi1))
+    else:
+      self.azi1 = azi1
+      """the azimuth at the first point in degrees (readonly)"""
+      self.salp1 = salp1
+      """the sine of the azimuth at the first point (readonly)"""
+      self.calp1 = calp1
+      """the cosine of the azimuth at the first point (readonly)"""
 
     # real cbet1, sbet1
     sbet1, cbet1 = Math.sincosd(Math.AngRound(lat1)); sbet1 *= self._f1
@@ -69,10 +118,10 @@ class GeodesicLine(object):
     self._dn1 = math.sqrt(1 + geod._ep2 * Math.sq(sbet1))
 
     # Evaluate alp0 from sin(alp1) * cos(bet1) = sin(alp0),
-    self._salp0 = self._salp1 * cbet1 # alp0 in [0, pi/2 - |bet1|]
+    self._salp0 = self.salp1 * cbet1 # alp0 in [0, pi/2 - |bet1|]
     # Alt: calp0 = hypot(sbet1, calp1 * cbet1).  The following
     # is slightly better (consider the case salp1 = 0).
-    self._calp0 = math.hypot(self._calp1, self._salp1 * sbet1)
+    self._calp0 = math.hypot(self.calp1, self.salp1 * sbet1)
     # Evaluate sig with tan(bet1) = tan(sig1) * cos(alp1).
     # sig = 0 is nearest northward crossing of equator.
     # With bet1 = 0, alp1 = pi/2, we have sig1 = 0 (equatorial line).
@@ -83,8 +132,8 @@ class GeodesicLine(object):
     # No atan2(0,0) ambiguity at poles since cbet1 = +epsilon.
     # With alp0 = 0, omg1 = 0 for alp1 = 0, omg1 = pi for alp1 = pi.
     self._ssig1 = sbet1; self._somg1 = self._salp0 * sbet1
-    self._csig1 = self._comg1 = (cbet1 * self._calp1
-                                 if sbet1 != 0 or self._calp1 != 0 else 1)
+    self._csig1 = self._comg1 = (cbet1 * self.calp1
+                                 if sbet1 != 0 or self.calp1 != 0 else 1)
     # sig1 in (-pi, pi]
     self._ssig1, self._csig1 = Math.norm(self._ssig1, self._csig1)
     # No need to normalize
@@ -93,58 +142,62 @@ class GeodesicLine(object):
     self._k2 = Math.sq(self._calp0) * geod._ep2
     eps = self._k2 / (2 * (1 + math.sqrt(1 + self._k2)) + self._k2)
 
-    if self._caps & Geodesic.CAP_C1:
-      self._A1m1 = Geodesic.A1m1f(eps)
+    if self.caps & Geodesic.CAP_C1:
+      self._A1m1 = Geodesic._A1m1f(eps)
       self._C1a = list(range(Geodesic.nC1_ + 1))
-      Geodesic.C1f(eps, self._C1a)
-      self._B11 = Geodesic.SinCosSeries(
+      Geodesic._C1f(eps, self._C1a)
+      self._B11 = Geodesic._SinCosSeries(
         True, self._ssig1, self._csig1, self._C1a)
       s = math.sin(self._B11); c = math.cos(self._B11)
       # tau1 = sig1 + B11
       self._stau1 = self._ssig1 * c + self._csig1 * s
       self._ctau1 = self._csig1 * c - self._ssig1 * s
       # Not necessary because C1pa reverts C1a
-      #    _B11 = -SinCosSeries(true, _stau1, _ctau1, _C1pa)
+      #    _B11 = -_SinCosSeries(true, _stau1, _ctau1, _C1pa)
 
-    if self._caps & Geodesic.CAP_C1p:
+    if self.caps & Geodesic.CAP_C1p:
       self._C1pa = list(range(Geodesic.nC1p_ + 1))
-      Geodesic.C1pf(eps, self._C1pa)
+      Geodesic._C1pf(eps, self._C1pa)
 
-    if self._caps & Geodesic.CAP_C2:
-      self._A2m1 = Geodesic.A2m1f(eps)
+    if self.caps & Geodesic.CAP_C2:
+      self._A2m1 = Geodesic._A2m1f(eps)
       self._C2a = list(range(Geodesic.nC2_ + 1))
-      Geodesic.C2f(eps, self._C2a)
-      self._B21 = Geodesic.SinCosSeries(
+      Geodesic._C2f(eps, self._C2a)
+      self._B21 = Geodesic._SinCosSeries(
         True, self._ssig1, self._csig1, self._C2a)
 
-    if self._caps & Geodesic.CAP_C3:
+    if self.caps & Geodesic.CAP_C3:
       self._C3a = list(range(Geodesic.nC3_))
-      geod.C3f(eps, self._C3a)
-      self._A3c = -self._f * self._salp0 * geod.A3f(eps)
-      self._B31 = Geodesic.SinCosSeries(
+      geod._C3f(eps, self._C3a)
+      self._A3c = -self.f * self._salp0 * geod._A3f(eps)
+      self._B31 = Geodesic._SinCosSeries(
         True, self._ssig1, self._csig1, self._C3a)
 
-    if self._caps & Geodesic.CAP_C4:
+    if self.caps & Geodesic.CAP_C4:
       self._C4a = list(range(Geodesic.nC4_))
-      geod.C4f(eps, self._C4a)
+      geod._C4f(eps, self._C4a)
       # Multiplier = a^2 * e^2 * cos(alpha0) * sin(alpha0)
-      self._A4 = Math.sq(self._a) * self._calp0 * self._salp0 * geod._e2
-      self._B41 = Geodesic.SinCosSeries(
+      self._A4 = Math.sq(self.a) * self._calp0 * self._salp0 * geod._e2
+      self._B41 = Geodesic._SinCosSeries(
         False, self._ssig1, self._csig1, self._C4a)
+    self.s13 = Math.nan
+    """the distance between point 1 and point 3 in meters (readonly)"""
+    self.a13 = Math.nan
+    """the arc length between point 1 and point 3 in degrees (readonly)"""
 
   # return a12, lat2, lon2, azi2, s12, m12, M12, M21, S12
-  def GenPosition(self, arcmode, s12_a12, outmask):
+  def _GenPosition(self, arcmode, s12_a12, outmask):
     """Private: General solution of position along geodesic"""
     from geographiclib.geodesic import Geodesic
     a12 = lat2 = lon2 = azi2 = s12 = m12 = M12 = M21 = S12 = Math.nan
-    outmask &= self._caps & Geodesic.OUT_MASK
+    outmask &= self.caps & Geodesic.OUT_MASK
     if not (arcmode or
-            (self._caps & Geodesic.DISTANCE_IN & Geodesic.OUT_MASK)):
+            (self.caps & (Geodesic.OUT_MASK & Geodesic.DISTANCE_IN))):
       # Uninitialized or impossible distance calculation requested
       return a12, lat2, lon2, azi2, s12, m12, M12, M21, S12
 
     # Avoid warning about uninitialized B12.
-    B12 = 0; AB1 = 0
+    B12 = 0.0; AB1 = 0.0
     if arcmode:
       # Interpret s12_a12 as spherical arc length
       sig12 = math.radians(s12_a12)
@@ -154,13 +207,13 @@ class GeodesicLine(object):
       tau12 = s12_a12 / (self._b * (1 + self._A1m1))
       s = math.sin(tau12); c = math.cos(tau12)
       # tau2 = tau1 + tau12
-      B12 = - Geodesic.SinCosSeries(True,
+      B12 = - Geodesic._SinCosSeries(True,
                                     self._stau1 * c + self._ctau1 * s,
                                     self._ctau1 * c - self._stau1 * s,
                                     self._C1pa)
       sig12 = tau12 - (B12 - self._B11)
       ssig12 = math.sin(sig12); csig12 = math.cos(sig12)
-      if abs(self._f) > 0.01:
+      if abs(self.f) > 0.01:
         # Reverted distance series is inaccurate for |f| > 1/100, so correct
         # sig12 with 1 Newton iteration.  The following table shows the
         # approximate maximum error for a = WGS_a() and various f relative to
@@ -184,7 +237,7 @@ class GeodesicLine(object):
         #      1/5   157e6 3.8e9 280e6
         ssig2 = self._ssig1 * csig12 + self._csig1 * ssig12
         csig2 = self._csig1 * csig12 - self._ssig1 * ssig12
-        B12 = Geodesic.SinCosSeries(True, ssig2, csig2, self._C1a)
+        B12 = Geodesic._SinCosSeries(True, ssig2, csig2, self._C1a)
         serr = ((1 + self._A1m1) * (sig12 + (B12 - self._B11)) -
                 s12_a12 / self._b)
         sig12 = sig12 - serr / math.sqrt(1 + self._k2 * Math.sq(ssig2))
@@ -199,8 +252,8 @@ class GeodesicLine(object):
     dn2 = math.sqrt(1 + self._k2 * Math.sq(ssig2))
     if outmask & (
       Geodesic.DISTANCE | Geodesic.REDUCEDLENGTH | Geodesic.GEODESICSCALE):
-      if arcmode or abs(self._f) > 0.01:
-        B12 = Geodesic.SinCosSeries(True, ssig2, csig2, self._C1a)
+      if arcmode or abs(self.f) > 0.01:
+        B12 = Geodesic._SinCosSeries(True, ssig2, csig2, self._C1a)
       AB1 = (1 + self._A1m1) * (B12 - self._B11)
     # sin(bet2) = cos(alp0) * sin(sig2)
     sbet2 = self._calp0 * ssig2
@@ -218,7 +271,7 @@ class GeodesicLine(object):
     if outmask & Geodesic.LONGITUDE:
       # tan(omg2) = sin(alp0) * tan(sig2)
       somg2 = self._salp0 * ssig2; comg2 = csig2 # No need to normalize
-      E = -1 if self._salp0 < 0 else 1           # East or west going?
+      E = Math.copysign(1, self._salp0)          # East or west going?
       # omg12 = omg2 - omg1
       omg12 = (E * (sig12
                     - (math.atan2(          ssig2,       csig2) -
@@ -229,22 +282,21 @@ class GeodesicLine(object):
                else math.atan2(somg2 * self._comg1 - comg2 * self._somg1,
                                comg2 * self._comg1 + somg2 * self._somg1))
       lam12 = omg12 + self._A3c * (
-        sig12 + (Geodesic.SinCosSeries(True, ssig2, csig2, self._C3a)
+        sig12 + (Geodesic._SinCosSeries(True, ssig2, csig2, self._C3a)
                  - self._B31))
       lon12 = math.degrees(lam12)
-      lon2 = (self._lon1 + lon12 if outmask & Geodesic.LONG_UNROLL else
-              Math.AngNormalize(Math.AngNormalize(self._lon1) +
+      lon2 = (self.lon1 + lon12 if outmask & Geodesic.LONG_UNROLL else
+              Math.AngNormalize(Math.AngNormalize(self.lon1) +
                                 Math.AngNormalize(lon12)))
 
     if outmask & Geodesic.LATITUDE:
       lat2 = Math.atan2d(sbet2, self._f1 * cbet2)
 
     if outmask & Geodesic.AZIMUTH:
-      # minus signs give range [-180, 180). 0- converts -0 to +0.
       azi2 = Math.atan2d(salp2, calp2)
 
     if outmask & (Geodesic.REDUCEDLENGTH | Geodesic.GEODESICSCALE):
-      B22 = Geodesic.SinCosSeries(True, ssig2, csig2, self._C2a)
+      B22 = Geodesic._SinCosSeries(True, ssig2, csig2, self._C2a)
       AB2 = (1 + self._A2m1) * (B22 - self._B21)
       J12 = (self._A1m1 - self._A2m1) * sig12 + (AB1 - AB2)
       if outmask & Geodesic.REDUCEDLENGTH:
@@ -260,18 +312,12 @@ class GeodesicLine(object):
         M21 = csig12 - (t * self._ssig1 - self._csig1 * J12) * ssig2 / dn2
 
     if outmask & Geodesic.AREA:
-      B42 = Geodesic.SinCosSeries(False, ssig2, csig2, self._C4a)
+      B42 = Geodesic._SinCosSeries(False, ssig2, csig2, self._C4a)
       # real salp12, calp12
       if self._calp0 == 0 or self._salp0 == 0:
         # alp12 = alp2 - alp1, used in atan2 so no need to normalize
-        salp12 = salp2 * self._calp1 - calp2 * self._salp1
-        calp12 = calp2 * self._calp1 + salp2 * self._salp1
-        # The right thing appears to happen if alp1 = +/-180 and alp2 = 0, viz
-        # salp12 = -0 and alp12 = -180.  However this depends on the sign being
-        # attached to 0 correctly.  The following ensures the correct behavior.
-        if salp12 == 0 and calp12 < 0:
-          salp12 = Geodesic.tiny_ * self._calp1
-          calp12 = -1
+        salp12 = salp2 * self.calp1 - calp2 * self.salp1
+        calp12 = calp2 * self.calp1 + salp2 * self.salp1
       else:
         # tan(alp) = tan(alp0) * sec(sig)
         # tan(alp2-alp1) = (tan(alp2) -tan(alp1)) / (tan(alp2)*tan(alp1)+1)
@@ -293,50 +339,26 @@ class GeodesicLine(object):
     return a12, lat2, lon2, azi2, s12, m12, M12, M21, S12
 
   def Position(self, s12, outmask = GeodesicCapability.STANDARD):
-    """Return the point a distance s12 along the geodesic line.  Return a
-    dictionary with (some) of the following entries:
+    """Find the position on the line given *s12*
 
-      lat1 latitude of point 1
-      lon1 longitude of point 1
-      azi1 azimuth of line at point 1
-      lat2 latitude of point 2
-      lon2 longitude of point 2
-      azi2 azimuth of line at point 2
-      s12 distance from 1 to 2
-      a12 arc length on auxiliary sphere from 1 to 2
-      m12 reduced length of geodesic
-      M12 geodesic scale 2 relative to 1
-      M21 geodesic scale 1 relative to 2
-      S12 area between geodesic and equator
+    :param s12: the distance from the first point to the second in
+      meters
+    :param outmask: the :ref:`output mask <outmask>`
+    :return: a :ref:`dict`
 
-    outmask determines which fields get included and if outmask is
-    omitted, then only the basic geodesic fields are computed.  The
-    LONG_UNROLL bit unrolls the longitudes (instead of reducing them to
-    the range [-180,180)), so that lon2 - lon1 indicates how many times
-    and in what sense the geodesic encircles the ellipsoid.  The mask is
-    an or'ed combination of the following values
-
-      Geodesic.LATITUDE
-      Geodesic.LONGITUDE
-      Geodesic.AZIMUTH
-      Geodesic.STANDARD (all of the above)
-      Geodesic.REDUCEDLENGTH
-      Geodesic.GEODESICSCALE
-      Geodesic.AREA
-      Geodesic.ALL (all of the above)
-      Geodesic.LONG_UNROLL
-
-    The default value of outmask is STANDARD.
+    The default value of *outmask* is STANDARD, i.e., the *lat1*,
+    *lon1*, *azi1*, *lat2*, *lon2*, *azi2*, *s12*, *a12* entries are
+    returned.  The :class:`~geographiclib.geodesicline.GeodesicLine`
+    object must have been constructed with the DISTANCE_IN capability.
 
     """
 
     from geographiclib.geodesic import Geodesic
-    Geodesic.CheckDistance(s12)
-    result = {'lat1': self._lat1,
-              'lon1': self._lon1 if outmask & Geodesic.LONG_UNROLL else
-              Math.AngNormalize(self._lon1),
-              'azi1': self._azi1, 's12': s12}
-    a12, lat2, lon2, azi2, s12, m12, M12, M21, S12 = self.GenPosition(
+    result = {'lat1': self.lat1,
+              'lon1': self.lon1 if outmask & Geodesic.LONG_UNROLL else
+              Math.AngNormalize(self.lon1),
+              'azi1': self.azi1, 's12': s12}
+    a12, lat2, lon2, azi2, s12, m12, M12, M21, S12 = self._GenPosition(
       False, s12, outmask)
     outmask &= Geodesic.OUT_MASK
     result['a12'] = a12
@@ -350,50 +372,25 @@ class GeodesicLine(object):
     return result
 
   def ArcPosition(self, a12, outmask = GeodesicCapability.STANDARD):
-    """Return the point a spherical arc length a12 along the geodesic line.
-    Return a dictionary with (some) of the following entries:
+    """Find the position on the line given *a12*
 
-      lat1 latitude of point 1
-      lon1 longitude of point 1
-      azi1 azimuth of line at point 1
-      lat2 latitude of point 2
-      lon2 longitude of point 2
-      azi2 azimuth of line at point 2
-      s12 distance from 1 to 2
-      a12 arc length on auxiliary sphere from 1 to 2
-      m12 reduced length of geodesic
-      M12 geodesic scale 2 relative to 1
-      M21 geodesic scale 1 relative to 2
-      S12 area between geodesic and equator
+    :param a12: spherical arc length from the first point to the second
+      in degrees
+    :param outmask: the :ref:`output mask <outmask>`
+    :return: a :ref:`dict`
 
-    outmask determines which fields get included and if outmask is
-    omitted, then only the basic geodesic fields are computed.  The
-    LONG_UNROLL bit unrolls the longitudes (instead of reducing them to
-    the range [-180,180)).  The mask is an or'ed combination of the
-    following values
-
-      Geodesic.LATITUDE
-      Geodesic.LONGITUDE
-      Geodesic.AZIMUTH
-      Geodesic.DISTANCE
-      Geodesic.STANDARD (all of the above)
-      Geodesic.REDUCEDLENGTH
-      Geodesic.GEODESICSCALE
-      Geodesic.AREA
-      Geodesic.ALL (all of the above)
-      Geodesic.LONG_UNROLL
-
-    The default value of outmask is STANDARD.
+    The default value of *outmask* is STANDARD, i.e., the *lat1*,
+    *lon1*, *azi1*, *lat2*, *lon2*, *azi2*, *s12*, *a12* entries are
+    returned.
 
     """
 
     from geographiclib.geodesic import Geodesic
-    Geodesic.CheckDistance(a12)
-    result = {'lat1': self._lat1,
-              'lon1': self._lon1 if outmask & Geodesic.LONG_UNROLL else
-              Math.AngNormalize(self._lon1),
-              'azi1': self._azi1, 'a12': a12}
-    a12, lat2, lon2, azi2, s12, m12, M12, M21, S12 = self.GenPosition(
+    result = {'lat1': self.lat1,
+              'lon1': self.lon1 if outmask & Geodesic.LONG_UNROLL else
+              Math.AngNormalize(self.lon1),
+              'azi1': self.azi1, 'a12': a12}
+    a12, lat2, lon2, azi2, s12, m12, M12, M21, S12 = self._GenPosition(
       True, a12, outmask)
     outmask &= Geodesic.OUT_MASK
     if outmask & Geodesic.DISTANCE: result['s12'] = s12
@@ -405,3 +402,25 @@ class GeodesicLine(object):
       result['M12'] = M12; result['M21'] = M21
     if outmask & Geodesic.AREA: result['S12'] = S12
     return result
+
+  def SetDistance(self, s13):
+    """Specify the position of point 3 in terms of distance
+
+    :param s13: distance from point 1 to point 3 in meters
+
+    """
+
+    self.s13 = s13
+    self.a13, _, _, _, _, _, _, _, _ = self._GenPosition(False, self.s13, 0)
+
+  def SetArc(self, a13):
+    """Specify the position of point 3 in terms of arc length
+
+    :param a13: spherical arc length from point 1 to point 3 in degrees
+
+    """
+
+    from geographiclib.geodesic import Geodesic
+    self.a13 = a13
+    _, _, _, _, self.s13, _, _, _, _ = self._GenPosition(True, self.a13,
+                                                         Geodesic.DISTANCE)
