@@ -444,6 +444,22 @@ class GeodSolveTest(unittest.TestCase):
     self.assertAlmostEqual(inv["M21"],   0.999999995, delta = 5e-9);
     self.assertAlmostEqual(inv["S12"], 286698586.30197, delta = 5e-4);
 
+  def test_GeodSolve76(self):
+    # The distance from Wellington and Salamanca (a classic failure of
+    # Vincenty)
+    inv = Geodesic.WGS84.Inverse(-(41+19/60.0), 174+49/60.0,
+                                 40+58/60.0, -(5+30/60.0))
+    self.assertAlmostEqual(inv["azi1"], 160.39137649664, delta = 0.5e-11)
+    self.assertAlmostEqual(inv["azi2"],  19.50042925176, delta = 0.5e-11)
+    self.assertAlmostEqual(inv["s12"],  19960543.857179, delta = 0.5e-6)
+
+  def test_GeodSolve78(self):
+    # An example where the NGS calculator fails to converge
+    inv = Geodesic.WGS84.Inverse(27.2, 0.0, -27.1, 179.5)
+    self.assertAlmostEqual(inv["azi1"],  45.82468716758, delta = 0.5e-11)
+    self.assertAlmostEqual(inv["azi2"], 134.22776532670, delta = 0.5e-11)
+    self.assertAlmostEqual(inv["s12"],  19974354.765767, delta = 0.5e-6)
+
 class PlanimeterTest(unittest.TestCase):
 
   polygon = Geodesic.WGS84.Polygon(False)
