@@ -2,8 +2,8 @@
  * \file GARS.cpp
  * \brief Implementation for GeographicLib::GARS class
  *
- * Copyright (c) Charles Karney (2015) <charles@karney.com> and licensed under
- * the MIT/X11 License.  For more information, see
+ * Copyright (c) Charles Karney (2015-2017) <charles@karney.com> and licensed
+ * under the MIT/X11 License.  For more information, see
  * https://geographiclib.sourceforge.io/
  **********************************************************************/
 
@@ -14,8 +14,8 @@ namespace GeographicLib {
 
   using namespace std;
 
-  const string GARS::digits_ = "0123456789";
-  const string GARS::letters_ = "ABCDEFGHJKLMNPQRSTUVWXYZ";
+  const char* const GARS::digits_ = "0123456789";
+  const char* const GARS::letters_ = "ABCDEFGHJKLMNPQRSTUVWXYZ";
 
   void GARS::Forward(real lat, real lon, int prec, std::string& gars) {
     if (abs(lat) > 90)
