@@ -2,7 +2,7 @@
  * \file Geocentric.cpp
  * \brief Implementation for GeographicLib::Geocentric class
  *
- * Copyright (c) Charles Karney (2008-2016) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2008-2017) <charles@karney.com> and licensed
  * under the MIT/X11 License.  For more information, see
  * https://geographiclib.sourceforge.io/
  **********************************************************************/
@@ -53,8 +53,8 @@ namespace GeographicLib {
                               real M[dim2_]) const {
     real
       R = Math::hypot(X, Y),
-      slam = R ? Y / R : 0,
-      clam = R ? X / R : 1;
+      slam = R != 0 ? Y / R : 0,
+      clam = R != 0 ? X / R : 1;
     h = Math::hypot(R, Z);      // Distance to center of earth
     real sphi, cphi;
     if (h > _maxrad) {
@@ -65,8 +65,8 @@ namespace GeographicLib {
       //
       // Treat the case X, Y finite, but R overflows to +inf by scaling by 2.
       R = Math::hypot(X/2, Y/2);
-      slam = R ? (Y/2) / R : 0;
-      clam = R ? (X/2) / R : 1;
+      slam = R != 0 ? (Y/2) / R : 0;
+      clam = R != 0 ? (X/2) / R : 1;
       real H = Math::hypot(Z/2, R);
       sphi = (Z/2) / H;
       cphi = R / H;
@@ -104,7 +104,7 @@ namespace GeographicLib {
           // N.B. cbrt always returns the real root.  cbrt(-8) = -2.
           real T = Math::cbrt(T3); // T = r * t
           // T can be zero; but then r2 / T -> 0.
-          u += T + (T ? r2 / T : 0);
+          u += T + (T != 0 ? r2 / T : 0);
         } else {
           // T is complex, but the way u is defined the result is real.
           real ang = atan2(sqrt(-disc), -(S + r3));
