@@ -2,7 +2,7 @@
  * \file Geohash.cpp
  * \brief Implementation for GeographicLib::Geohash class
  *
- * Copyright (c) Charles Karney (2012-2015) <charles@karney.com> and licensed
+ * Copyright (c) Charles Karney (2012-2017) <charles@karney.com> and licensed
  * under the MIT/X11 License.  For more information, see
  * https://geographiclib.sourceforge.io/
  **********************************************************************/
@@ -14,11 +14,11 @@ namespace GeographicLib {
 
   using namespace std;
 
-  const string Geohash::lcdigits_ = "0123456789bcdefghjkmnpqrstuvwxyz";
-  const string Geohash::ucdigits_ = "0123456789BCDEFGHJKMNPQRSTUVWXYZ";
+  const char* const Geohash::lcdigits_ = "0123456789bcdefghjkmnpqrstuvwxyz";
+  const char* const Geohash::ucdigits_ = "0123456789BCDEFGHJKMNPQRSTUVWXYZ";
 
   void Geohash::Forward(real lat, real lon, int len, std::string& geohash) {
-    static const real shift = pow(real(2), 45);
+    static const real shift = ldexp(real(1), 45);
     static const real loneps = 180 / shift;
     static const real lateps =  90 / shift;
     if (abs(lat) > 90)
@@ -58,7 +58,7 @@ namespace GeographicLib {
 
   void Geohash::Reverse(const std::string& geohash, real& lat, real& lon,
                         int& len, bool centerp) {
-    static const real shift = pow(real(2), 45);
+    static const real shift = ldexp(real(1), 45);
     static const real loneps = 180 / shift;
     static const real lateps =  90 / shift;
     int len1 = min(int(maxlen_), int(geohash.length()));
