@@ -28,8 +28,7 @@ namespace GeographicLib {
   {}
 
   void Gnomonic::Forward(real lat0, real lon0, real lat, real lon,
-                         real& x, real& y, real& azi, real& rk)
-    const {
+                         real& x, real& y, real& azi, real& rk) const {
     real azi0, m, M, t;
     _earth.GenInverse(lat0, lon0, lat, lon,
                       Geodesic::AZIMUTH | Geodesic::REDUCEDLENGTH |
@@ -46,8 +45,7 @@ namespace GeographicLib {
   }
 
   void Gnomonic::Reverse(real lat0, real lon0, real x, real y,
-                         real& lat, real& lon, real& azi, real& rk)
-    const {
+                         real& lat, real& lon, real& azi, real& rk) const {
     real
       azi0 = Math::atan2d(x, y),
       rho = Math::hypot(x, y),
